import numpy as np
import matplotlib.pyplot as plt

A = np.loadtxt( "datos.csv", delimiter=',' )

X = A[:,0:2]
y = A[:,2]

vys = np.array( [0.36607143, 0.33928571, 0.29464286] )

# [41. 38. 33.]
# [0. 1. 2.]
# 1.3700782687420282e-08

# Varianza y medias por característica y clase 
# Las columnas son las características
# El renglón es cada clase
# 3 x 2, 3 clases y 2 características
Sigs = np.array( [[1.0767069,  1.44333791],
                  [1.42237467, 1.47367389],
                  [1.22955   , 1.12874638]] )
Meds = np.array( [[ 4.58880488,  4.12690244],
                  [-2.86107895,  2.91157895],
                  [-0.13978788, -4.08157576]] )


def predict( x ) :
	# Tenemos que hacer las sumas por clase y característica

	vclas = np.zeros( (1,3) )

	i = 0
	while i < 3 :
		suma = np.log( vys[i] )

		# Sumas por característica
		j = 0
		while j < 2 :
			suma -= 0.5*np.log( 2*np.pi*Sigs[i,j] )
			j += 1

		j = 0
		while j < 2 :
			v = x[0,j] - Meds[i,j] 
			suma -= 0.5*v*v/Sigs[i,j]
			j += 1

		vclas[0,i] = suma
		i += 1

	etiqueta = np.array( [0, 1, 2] )

	return etiqueta[ np.argmax( vclas ) ]
	


print( predict( np.array( [[6,4]] )  ) )
print( predict( np.array( [[-2,4]] )  ) )
print( predict( np.array( [[0,-4]] )  ) )


fig, ax = plt.subplots( )

ax.set_aspect( 1 )

# Create grid values first.
n = 100
xi = np.linspace(-6, 8, n)
yi = np.linspace(-8, 8, n)
vx, vy = np.meshgrid( xi, yi )

vv = np.zeros( (1,2) )
zi = np.zeros( (n,n) )
i = 0
while i < n :
	vv[0,1] = yi[i]
	j = 0
	while j < n :
		vv[0,0] = xi[j]
		zi[i,j] = predict( vv ) 
		j += 1
	i += 1

# Linearly interpolate the data (x, y) on a grid defined by (xi, yi).

ax.set_xlim( (-6,8) )
ax.set_ylim( (-8,8) )

# Para poner la escala del color:
cntr = ax.contourf(vx, vy, zi )
fig.colorbar(cntr, ax=ax)

# Los puntos
ax.scatter( X[:,0], X[:,1], c=y )

# Los vectores de soporte en rojo
# ax.scatter( svec[:,0], svec[:,1], c='red' )

plt.show( )

